@@ -2,7 +2,7 @@ package Dist::Zilla::MintingProfile::Pcore;
 
 use Moose;
 use Pcore;
-use Path::Class();
+use Path::Class qw[];
 
 with qw[Dist::Zilla::Role::MintingProfile];
 
