@@ -138,7 +138,10 @@ sub configure {
         # NOTE need to set $ENV{MODULE_SIGNATURE_AUTHOR} = q["<author-email>"];
         # [ 'Signature' => { sign => 'always' } ],
 
-        ['UploadToCPAN']
+        # release
+        ['TestRelease'],
+        ['ConfirmRelease'],
+        ['Pcore::UploadToCPAN'],
     );
 
     return;
