@@ -199,7 +199,7 @@ sub _deploy_nginx_cfg {
     my $params = {
         app_name          => $self->name,
         app_dir           => $self->app_dir,
-        resources_dir     => $DIST->{RESOURCES_DIR} . 'share/',
+        resources_dir     => P->res->dist_dir . 'share/',
         log_dir           => $PROC->{LOG_DIR},
         use_ssl           => 0,                                      # TODO
         server_name       => $self->cfg->{PSGI}->{SERVER}->{name},
