@@ -15,4 +15,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Core::Autoload::Package
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
