@@ -42,7 +42,6 @@ sub CORE_INIT {
     _configure_inc();
 
     # configure $PROC run-time dirs
-    $PROC->{RESOURCES_DIR} = $PROC->{RESOURCES_DIR} && -d $PROC->{RESOURCES_DIR} ? P->file->path( $PROC->{RESOURCES_DIR}, is_dir => 1 )->realpath->to_string : q[];
     $PROC->{LOG_DIR}  = $PROC->{LOG_DIR}  ? P->file->path( $PROC->{LOG_DIR},  is_dir => 1, lazy => 1 ) : $DIST->{LOG_DIR};
     $PROC->{DATA_DIR} = $PROC->{DATA_DIR} ? P->file->path( $PROC->{DATA_DIR}, is_dir => 1, lazy => 1 ) : $DIST->{DATA_DIR};
     $PROC->{TMPL_DIR} = $PROC->{TMPL_DIR} && -d $PROC->{TMPL_DIR} ? P->file->path( $PROC->{TMPL_DIR}, is_dir => 1 )->realpath->to_string : q[];
@@ -78,27 +77,24 @@ sub _configure_dist {
             File::ShareDir::dist_dir( $DIST->{dist}->{name} );
         };
 
-        $DIST->{ROOT}          = q[];
-        $DIST->{SHARE_DIR}     = $dist_share_dir ? P->file->path( $dist_share_dir, is_dir => 1 )->realpath->to_string : q[];
-        $DIST->{LOG_DIR}       = P->file->path( $ENV{PAR_TEMP} . '/log/', is_dir => 1, lazy => 1 );
-        $DIST->{DATA_DIR}      = q[];
-        $DIST->{RESOURCES_DIR} = -d $ENV{PAR_TEMP} . '/inc/resources/' ? P->file->path( $ENV{PAR_TEMP} . '/inc/resources/', is_dir => 1 )->realpath->to_string : q[];
+        $DIST->{ROOT}      = q[];
+        $DIST->{SHARE_DIR} = $dist_share_dir ? P->file->path( $dist_share_dir, is_dir => 1 )->realpath->to_string : q[];
+        $DIST->{LOG_DIR}   = P->file->path( $ENV{PAR_TEMP} . '/log/', is_dir => 1, lazy => 1 );
+        $DIST->{DATA_DIR}  = q[];
     }
     elsif ( my $dist_root = find_dist_root( $PROC->{SCRIPT_DIR} ) ) {    # script located in dist location
         $DIST = P->cfg->load( $dist_root . 'share/dist.perl' );
 
-        $DIST->{ROOT}          = $dist_root->to_string;
-        $DIST->{SHARE_DIR}     = $DIST->{ROOT} . 'share/';
-        $DIST->{LOG_DIR}       = P->file->path( $DIST->{ROOT} . 'log/', is_dir => 1, lazy => 1 );
-        $DIST->{DATA_DIR}      = P->file->path( $DIST->{ROOT} . 'data/', is_dir => 1, lazy => 1 );
-        $DIST->{RESOURCES_DIR} = -d $DIST->{ROOT} . 'resources/' ? $DIST->{ROOT} . 'resources/' : q[];
+        $DIST->{ROOT}      = $dist_root->to_string;
+        $DIST->{SHARE_DIR} = $DIST->{ROOT} . 'share/';
+        $DIST->{LOG_DIR}   = P->file->path( $DIST->{ROOT} . 'log/', is_dir => 1, lazy => 1 );
+        $DIST->{DATA_DIR}  = P->file->path( $DIST->{ROOT} . 'data/', is_dir => 1, lazy => 1 );
     }
     else {                                                               # script located in unknown location
-        $DIST->{ROOT}          = q[];
-        $DIST->{SHARE_DIR}     = q[];
-        $DIST->{LOG_DIR}       = q[];
-        $DIST->{DATA_DIR}      = q[];
-        $DIST->{RESOURCES_DIR} = q[];
+        $DIST->{ROOT}      = q[];
+        $DIST->{SHARE_DIR} = q[];
+        $DIST->{LOG_DIR}   = q[];
+        $DIST->{DATA_DIR}  = q[];
     }
 
     # create $DIST share dir shortcuts
@@ -124,9 +120,8 @@ sub _configure_p {
         else {                                                # Pcore dist is separate
             $P = P->cfg->load( $p_root . 'share/dist.perl' );
 
-            $P->{ROOT}          = $p_root;
-            $P->{SHARE_DIR}     = $P->{ROOT} . 'share/';
-            $P->{RESOURCES_DIR} = -d $P->{ROOT} . 'resources/' ? $P->{ROOT} . 'resources/' : $ENV{PCORE_RESOURCES} && -d $ENV{PCORE_RESOURCES} ? P->file->path( $ENV{PCORE_RESOURCES}, is_dir => 1 )->realpath : q[];
+            $P->{ROOT}      = $p_root;
+            $P->{SHARE_DIR} = $P->{ROOT} . 'share/';
         }
 
         # define inline dir location
@@ -137,9 +132,8 @@ sub _configure_p {
 
         $P = P->cfg->load( $p_share_dir . 'dist.perl' );
 
-        $P->{ROOT}          = q[];
-        $P->{SHARE_DIR}     = $p_share_dir;
-        $P->{RESOURCES_DIR} = $ENV{PCORE_RESOURCES} && -d $ENV{PCORE_RESOURCES} ? P->file->path( $ENV{PCORE_RESOURCES}, is_dir => 1 )->realpath : q[];
+        $P->{ROOT}      = q[];
+        $P->{SHARE_DIR} = $p_share_dir;
 
         # define inline dir location
         if ($Pcore::IS_PAR) {                                 # Pcore PAR inline dir location
@@ -273,10 +267,10 @@ sub _dir_is_dist_root {
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
 ## │    3 │ 10                   │ ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 259                  │ ValuesAndExpressions::ProhibitMismatchedOperators - Mismatched operator                                        │
+## │    3 │ 253                  │ ValuesAndExpressions::ProhibitMismatchedOperators - Mismatched operator                                        │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 45, 48, 49, 61, 82,  │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
-## │      │ 85, 136, 178         │                                                                                                                │
+## │    2 │ 47, 48, 60, 81, 131, │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
+## │      │ 172                  │                                                                                                                │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
