@@ -59,7 +59,7 @@ sub core_cli_event {
 
 =item -D | --daemonize
 
-Daemonize script. *nix only.
+Daemonize the process.
 
 =item --UID [=] <uid>
 
@@ -81,8 +81,6 @@ POD
 
     # add service POD
     if ( $PROC->{SERVICE_NAME} ) {
-
-        # NOTE HEREDOC dies on windows, I don't know why
         my $pod = <<'POD';
 =pod
 
@@ -109,6 +107,7 @@ POD
         unshift $pods, $service_pod_fh;
     }
 
+    # process POD
     {
         local $SIG{__WARN__} = sub { };
 
@@ -139,6 +138,7 @@ POD
 
     # store uid and gid
     $PROC->{GID} = $ARGV{GID} if $ARGV{GID};
+
     $PROC->{UID} = $ARGV{UID} if $ARGV{UID};
 
     # daemonize
@@ -183,16 +183,6 @@ TXT
 }
 
 1;
-## -----SOURCE FILTER LOG BEGIN-----
-##
-## PerlCritic profile "pcore-script" policy violations:
-## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
-## │ Sev. │ Lines                │ Policy                                                                                                         │
-## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    1 │ 197                  │ Documentation::RequirePackageMatchesPodName - Pod NAME on line 201 does not match the package declaration      │
-## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
-##
-## -----SOURCE FILTER LOG END-----
 __END__
 =pod
 
@@ -200,7 +190,7 @@ __END__
 
 =head1 NAME
 
-Pcore::CORE::CLI - pcore CLI interface
+Pcore::Core::CLI - pcore CLI interface
 
 =head1 SYNOPSIS
 
