@@ -1,15 +1,14 @@
 package Pcore::Core::Constants;
 
-BEGIN {
-    our %EXPORT_TAGS = (    #
-        DEFAULT => [qw[$MSWIN $CRLF $LF $TRUE $FALSE $P $DIST $PROC $STDIN $STDOUT $STDERR]],
-        CORE    => [qw[$MSWIN $CRLF $LF $TRUE $FALSE $P $DIST $PROC $STDIN $STDOUT $STDERR]],
-    );
-}
-
 use Pcore qw[-export];
-use Const::Fast();
-use Types::Serialiser();    ## no critic qw(Modules::ProhibitEvilModules)
+use Const::Fast qw[];
+use Types::Serialiser qw[];    ## no critic qw(Modules::ProhibitEvilModules)
+
+our @EXPORT_OK   = qw[$MSWIN $CRLF $LF $TRUE $FALSE $P $DIST $PROC $STDIN $STDOUT $STDERR];
+our %EXPORT_TAGS = (                                                                          #
+    CORE => \@EXPORT_OK
+);
+our @EXPORT = @EXPORT_OK;
 
 our $P;
 our $DIST;
@@ -31,4 +30,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Core::Constants
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
