@@ -38,4 +38,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Core::H::Role::Wrapper
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
