@@ -47,6 +47,9 @@ sub BUILDARGS ( $self, $args = undef ) {
     if ( $args->{on_progress} && ref $args->{on_progress} ne 'CODE' ) {
         $args->{on_progress} = $self->_get_progress_bar_cb( ref $args->{on_progress} eq 'HASH' ? $args->{on_progress}->%* : () );
     }
+    else {
+        delete $args->{on_progress};
+    }
 
     $args->{cookie_jar} = Pcore::HTTP::CookieJar->new if $args->{cookie_jar} && $args->{cookie_jar} == 1;
 
