@@ -151,7 +151,7 @@ sub compress ( $self, % ) {
     state $cache;
 
     if ( !$cache ) {
-        tie my %cache, 'BerkeleyDB::Hash', -Filename => $PROC->{SYS_TEMP_DIR} . '.percompress.bdb', -Flags => BerkeleyDB::DB_CREATE();
+        tie my %cache, 'BerkeleyDB::Hash', -Filename => $PROC->{SYS_TEMP_DIR} . 'perl_compress.bdb', -Flags => BerkeleyDB::DB_CREATE();
 
         $cache = \%cache;
     }
