@@ -7,7 +7,8 @@ use overload    #
     my $self = shift;
 
     return $self->old_umask;
-  };
+  },
+  fallback => undef;
 
 has old_umask => ( is => 'ro', isa => Int, required => 1 );
 
