@@ -1,7 +1,7 @@
 package Pcore::Util::Text::Table;
 
 use Pcore qw[-class];
-use Text::ASCIITable();    ## no critic qw(Modules::ProhibitEvilModules)
+use Text::ASCIITable qw[];    ## no critic qw(Modules::ProhibitEvilModules)
 
 has row_line => ( is => 'ro', isa => Bool, default => 1 );
 has _protect_spaces => ( is => 'rw', isa => Bool, default => 0, init_arg => undef );
@@ -78,4 +78,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Util::Text::Table
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
