@@ -381,7 +381,27 @@ sub _build_root_domain ($self) {
 }
 
 sub _build_pub_suffix ($self) {
-    state $suffixes = { map { $_ => 1 } grep { index( $_, q[//] ) == -1 } P->file->read_lines( P->res->get_local('effective_tld_names.dat') )->@* };
+    state $suffixes = do {
+        my $_suffixes;
+
+        my $path = P->res->get_local('effective_tld_names.dat');
+
+        if ( !$path ) {
+            P->ua->request(
+                'https://publicsuffix.org/list/effective_tld_names.dat',
+                chunk_size  => 0,
+                on_progress => 0,
+                blocking    => 1,
+                on_finish   => sub ($res) {
+                    $path = P->res->store_local( 'effective_tld_names.dat', $res->body ) if $res->status == 200;
+
+                    return;
+                }
+            );
+        }
+
+        $_suffixes = { map { $_ => 1 } grep { index( $_, q[//] ) == -1 } P->file->read_lines($path)->@* };
+    };
 
     if ( my $host = $self->canon_domain ) {
         return $host if exists $suffixes->{$host};
