@@ -1,7 +1,7 @@
 package Pcore::Util::UUID;
 
 use Pcore;
-use Data::UUID();    ## no critic qw(Modules::ProhibitEvilModules)
+use Data::UUID qw[];    ## no critic qw(Modules::ProhibitEvilModules)
 
 sub str {
     my $self = shift;
@@ -27,4 +27,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Util::UUID
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
